==> kubernetes-model-core-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/PodTemplateSpecFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodTemplateSpecFluent<A extends PodTemplateSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> withNewMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PodTemplateSpecFluent.MetadataNested<A> editMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSpec getSpec();
  public PodSpec buildSpec();
  public A withSpec(PodSpec spec);
  public Boolean hasSpec();
  public PodTemplateSpecFluent.SpecNested<A> withNewSpec();
  public PodTemplateSpecFluent.SpecNested<A> withNewSpecLike(PodSpec item);
  public PodTemplateSpecFluent.SpecNested<A> editSpec();
  public PodTemplateSpecFluent.SpecNested<A> editOrNewSpec();
  public PodTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(PodSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PodTemplateSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,PodSpecFluent<PodTemplateSpecFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/PodTemplateSpecFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodTemplateSpecFluent<A extends PodTemplateSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> withNewMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PodTemplateSpecFluent.MetadataNested<A> editMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
  public PodTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSpec getSpec();
  public PodSpec buildSpec();
  public A withSpec(PodSpec spec);
  public Boolean hasSpec();
  public PodTemplateSpecFluent.SpecNested<A> withNewSpec();
  public PodTemplateSpecFluent.SpecNested<A> withNewSpecLike(PodSpec item);
  public PodTemplateSpecFluent.SpecNested<A> editSpec();
  public PodTemplateSpecFluent.SpecNested<A> editOrNewSpec();
  public PodTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(PodSpec item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PodTemplateSpecFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,PodSpecFluent<PodTemplateSpecFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
